@@ -16,10 +16,14 @@
 #include "wavealloca.h"
 #include <string.h>
 #include <stdlib.h>
-#include <fnmatch.h>
+/* #include <fnmatch.h> */
+#ifdef MAC_INTEGRATION
+#include <cocoa_misc.h>
+#endif
 
 #if GTK_CHECK_VERSION(2,4,0)
 
+#ifndef MAC_INTEGRATION
 static gboolean ffunc (const GtkFileFilterInfo *filter_info, gpointer data)
 {
 const char *rms = strrchr(filter_info->filename, '\\');
@@ -46,7 +50,6 @@ if(!strchr(GLOBALS->pFileChooseFilterName, '*') && !strchr(GLOBALS->pFileChooseF
 	}
 }
 
-
 static
 void filter_edit_cb (GtkWidget *widget, GdkEventKey *ev, gpointer *data)
 {
@@ -93,6 +96,7 @@ filter_edit_cb (widget, &ev, data);
 }
 
 #endif
+#endif
 
 
 static void enter_callback(GtkWidget *widget, GtkFileSelection *fw)
@@ -158,6 +162,7 @@ wave_gtk_grab_add(GLOBALS->fs_file_c_1);
 
 void fileselbox(char *title, char **filesel_path, GtkSignalFunc ok_func, GtkSignalFunc notok_func, char *pattn, int is_writemode)
 {
+#ifndef MAC_INTEGRATION
 int can_set_filename = 0;
 #if GTK_CHECK_VERSION(2,4,0)
 GtkWidget *pFileChoose;
@@ -169,6 +174,7 @@ GtkWidget *box;
 GtkTooltips *tooltips;
 struct Global *old_globals = GLOBALS;
 #endif
+#endif
 
 /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
 if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
@@ -192,7 +198,7 @@ if(!*filesel_path) /* if no name specified, hijack loaded file name path */
 		}
 	}
 
- 
+
 if(GLOBALS->wave_script_args)
 	{
 	char *s = NULL;
@@ -215,6 +221,27 @@ if(GLOBALS->wave_script_args)
 	return;
 	}
 
+#ifdef MAC_INTEGRATION
+
+GLOBALS->fileselbox_text=filesel_path;
+GLOBALS->filesel_ok=0;
+char *rc = gtk_file_req_bridge(title, *filesel_path, pattn, is_writemode); 
+if(rc)
+	{
+        GLOBALS->filesel_ok=1;
+
+        if(*GLOBALS->fileselbox_text) free_2(*GLOBALS->fileselbox_text);
+        *GLOBALS->fileselbox_text=strdup_2(rc);
+	g_free(rc);
+	if(ok_func) ok_func();
+	}
+	else
+	{
+	if(notok_func) notok_func();
+	}
+return;
+
+#else
 
 #if defined __MINGW32__ || !GTK_CHECK_VERSION(2,4,0)
 
@@ -464,6 +491,8 @@ if(GLOBALS->pPatternSpec)
 	GLOBALS->pPatternSpec = NULL;
 	}
 
+#endif
+
 #endif
 }
 
