@@ -133,6 +133,9 @@ void helpbox(char *title, int width, char *default_text)
     GtkWidget *label, *separator;
     GtkWidget *ctext;
 
+    /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
+    if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
     if(GLOBALS->helpbox_is_active) return;
     GLOBALS->helpbox_is_active=1;
 
