@@ -37,7 +37,7 @@ printf(
 "  -f, --fstname=FILE         specify FST input filename\n"
 "  -h, --help                 display this help then exit\n\n"
 "VCD is emitted to stdout.\n\n"
-"Report bugs to <bybell@nc.rr.com>.\n",nam);
+"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
 #else
 printf(
 "Usage: %s [OPTION]... [FSTFILE]\n\n"
@@ -45,7 +45,7 @@ printf(
 "  -h                         display this help then exit\n\n"
 
 "FST is emitted to stdout.\n\n"
-"Report bugs to <bybell@nc.rr.com>.\n",nam);
+"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
 #endif
 
 exit(0);
