@@ -229,11 +229,13 @@ WV_MENU_MSCMD,
 WV_MENU_MDNM,
 WV_MENU_MCNM,
 WV_MENU_MCANM,
+WV_MENU_MCAB,
 WV_MENU_MDPM,
 WV_MENU_SEP8,
 WV_MENU_SLE,
 WV_MENU_SRE,
 WV_MENU_SEP8B,
+WV_MENU_HSWM,
 WV_MENU_MWSON,
 WV_MENU_MLKLT, 
 WV_MENU_MLKRT, 
