@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2006-2009.
+ * Copyright (c) Tony Bybell 2006-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -70,10 +70,19 @@ if((flags & TR_ONEFILL) != 0) { ch[pos++] = '1'; }
 /* [9] */
 if((flags & TR_BINGRAY) != 0) { ch[pos++] = 'G'; }
 
-/* [10]  (at worst case this needs 11 characters) */
+/* [10] */
 if((flags & TR_GRAYBIN) != 0) { ch[pos++] = 'g'; }
 
-/* [11]  (at worst case this needs 12 characters) */
+/* [11] */
+if((flags & TR_FTRANSLATED) != 0) { ch[pos++] = 'F'; }
+
+/* [12] */
+if((flags & TR_PTRANSLATED) != 0) { ch[pos++] = 'P'; }
+
+/* [13] */
+if((flags & TR_TTRANSLATED) != 0) { ch[pos++] = 'T'; }
+
+/* [14]  (at worst case this needs 14 characters) */
 ch[pos] = 0;
 
 return(pos);
