@@ -115,6 +115,9 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
 
     GLOBALS->cleanup_e_search_c_2=func;
 
+    /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
+    if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
     /* create a new modal window */
     GLOBALS->window1_search_c_2 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
     install_focus_cb(GLOBALS->window1_search_c_2, ((char *)&GLOBALS->window1_search_c_2) - ((char *)GLOBALS));
@@ -890,6 +893,9 @@ void searchbox(char *title, GtkSignalFunc func)
     GtkAdjustment *adj;
     GtkWidget *align;
 
+    /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
+    if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
     if(GLOBALS->is_active_search_c_4) 
 	{
 	gdk_window_raise(GLOBALS->window_search_c_7->window);
