@@ -307,6 +307,8 @@ guint64 nval;
 char buf[33];
 char *pnt;
 
+memset(buf, 0, sizeof(buf)); /* scan-build */
+
 vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, (guint64)mystat->st_size);
 vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, (guint64)mystat->st_mtime);
 
@@ -532,17 +534,17 @@ enum Tokens   { T_VAR, T_END, T_SCOPE, T_UPSCOPE,
 		T_COMMENT, T_DATE, T_DUMPALL, T_DUMPOFF, T_DUMPON,
 		T_DUMPVARS, T_ENDDEFINITIONS, 
 		T_DUMPPORTS, T_DUMPPORTSOFF, T_DUMPPORTSON, T_DUMPPORTSALL,
-		T_TIMESCALE, T_VERSION, T_VCDCLOSE,
+		T_TIMESCALE, T_VERSION, T_VCDCLOSE, T_TIMEZERO,
 		T_EOF, T_STRING, T_UNKNOWN_KEY };
 
 static char *tokens[]={ "var", "end", "scope", "upscope",
                  "comment", "date", "dumpall", "dumpoff", "dumpon",
                  "dumpvars", "enddefinitions",
                  "dumpports", "dumpportsoff", "dumpportson", "dumpportsall",
-                 "timescale", "version", "vcdclose",
+                 "timescale", "version", "vcdclose", "timezero",
                  "", "", "" };
 
-#define NUM_TOKENS 18
+#define NUM_TOKENS 19
 
 
 #define T_GET tok=get_token();if((tok==T_END)||(tok==T_EOF))break;
@@ -1398,6 +1400,16 @@ for(;;)
 		case T_VERSION:
 			disable_autocoalesce = version_sync_end("VERSION:");
 			break;
+		case T_TIMEZERO:
+			{
+			int vtok=get_token();
+			if((vtok==T_END)||(vtok==T_EOF)) break;
+			GLOBALS->global_time_offset=atoi_64(GLOBALS->yytext_vcd_recoder_c_3);
+
+			DEBUG(fprintf(stderr,"TIMEZERO: "TTFormat"\n",GLOBALS->global_time_offset));
+			sync_end(NULL);
+			}
+			break;
 		case T_TIMESCALE:
 			{
 			int vtok;
@@ -2838,6 +2850,7 @@ if(GLOBALS->vcd_is_compressed_vcd_recoder_c_2)
 
 GLOBALS->min_time=GLOBALS->start_time_vcd_recoder_c_3*GLOBALS->time_scale;
 GLOBALS->max_time=GLOBALS->end_time_vcd_recoder_c_3*GLOBALS->time_scale;
+GLOBALS->global_time_offset = GLOBALS->global_time_offset * GLOBALS->time_scale;
 
 if((GLOBALS->min_time==GLOBALS->max_time)&&(GLOBALS->max_time==LLDescriptor(-1)))
         {
